{pkgs}: let
  taskfile = builtins.toFile "taskfile.yml" ''
    version: '3'

    tasks:
      default:
        cmds:
          - task --list
        silent: true
      run-tests:
        desc: Execute all tests.
        aliases:
          - rt
        env:
          TEST_BY_TASK: true
        cmds:
          - run-tests
        silent: true

      run-extended-tests:
        desc: Execute all tests including cover, bench and race tests.
        aliases:
          - ret
        env:
          TEST_BY_TASK: true
        cmds:
          - run-extended-tests
        silent: true

      build-cover-report:
        desc: Build coverage report.
        aliases:
          - cr
        env:
          TEST_BY_TASK: true
        cmds:
          - build-cover-report
        silent: true

      check-code:
        desc: Check code style, linting, and formatting.
        aliases:
          - cc
        env:
          USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
        cmds:
          - check-code
        silent: true

      git-commit:
        desc: Commit changes.
        aliases:
          - gc
          - commit
        cmds:
          - check-code
          - cd "{{.USER_WORKING_DIR}}" && cd $(git rev-parse --show-toplevel) && nix run git+https://gitlab.schukai.com/schukai/entwicklung/nix-flakes#git-commit --no-write-lock-file
        silent: true
        env:
          USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"


  '';
in
  pkgs.writeShellScriptBin "task" ''
    ${pkgs.go-task}/bin/task -t "${taskfile}" "$@"
  ''
